@@ -158,7 +158,7 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 		return nil, nil, err
 	}
 
-	appName, appNameExplanation, err := determineAppName(ctx, appConfig, configPath)
+	appName, appNameExplanation, err := determineAppName(ctx, parentConfig, appConfig, configPath)
 	if err != nil {
 		if err := recoverableErrors.tryRecover(err); err != nil {
 			return nil, nil, err
@@ -420,11 +420,11 @@ func determineBaseAppConfig(ctx context.Context) (*appconfig.Config, bool, error
 			fmt.Fprintln(io.Out, "An existing fly.toml file was found")
 		}
 
-		// if both --from and --into are specified, we should return the config as the base config
-		fromInto := (flag.GetString(ctx, "from") != "" || flag.GetString(ctx, "image") != "") && (flag.GetString(ctx, "into") != "")
-		copyConfig := flag.GetBool(ctx, "copy-config") || fromInto
+		// if --attach is specified, we should return the config as the base config
+		attach := flag.GetBool(ctx, "attach")
+		copyConfig := flag.GetBool(ctx, "copy-config") || attach
 
-		if !flag.IsSpecified(ctx, "copy-config") && !fromInto {
+		if !flag.IsSpecified(ctx, "copy-config") && !attach && !flag.GetYes(ctx) {
 			var err error
 			copyConfig, err = prompt.Confirm(ctx, "Would you like to copy its configuration to the new app?")
 			switch {
@@ -481,7 +481,7 @@ func validateAppName(appName string) error {
 }
 
 // determineAppName determines the app name from the config file or directory name
-func determineAppName(ctx context.Context, appConfig *appconfig.Config, configPath string) (string, string, error) {
+func determineAppName(ctx context.Context, parentConfig *appconfig.Config, appConfig *appconfig.Config, configPath string) (string, string, error) {
 	delimiter := "-"
 	findUniqueAppName := func(prefix string) (string, bool) {
 		// Remove any existing haikus so we don't keep adding to the end.
@@ -525,6 +525,19 @@ func determineAppName(ctx context.Context, appConfig *appconfig.Config, configPa
 			appName = sanitizeAppName(filepath.Base(filepath.Dir(configPath)))
 			cause = "derived from your directory name"
 		}
+
+		if parentConfig != nil && parentConfig.AppName != "" {
+			appName = parentConfig.AppName + "-" + appName
+			if cause == "from your fly.toml" {
+				cause = "from parent name and fly.toml"
+			} else if cause == "derived from your directory name" {
+				if flag.GetString(ctx, "into") != "" {
+					cause = "from parent name and --into"
+				} else if flag.GetString(ctx, "from") != "" {
+					cause = "from parent name and --from"
+				}
+			}
+		}
 	}
 
 	taken := appName == ""
@@ -575,8 +588,7 @@ func appNameTaken(ctx context.Context, name string) (bool, error) {
 func determineOrg(ctx context.Context, config *appconfig.Config) (*fly.Organization, string, error) {
 	client := flyutil.ClientFromContext(ctx)
 
-	frominto := (flag.GetString(ctx, "from") != "" || flag.GetString(ctx, "image") != "") && flag.GetString(ctx, "into") != ""
-	if frominto && config != nil && config.AppName != "" {
+	if flag.GetBool(ctx, "attach") && config != nil && config.AppName != "" {
 		org, err := client.GetOrganizationByApp(ctx, config.AppName)
 		if err == nil {
 			return org, fmt.Sprintf("from %s app", config.AppName), nil
